@@ -67,3 +67,7 @@ def main():
                 balsheet_date, levels=int(args["--levels"])
             )
         )
+
+
+if __name__ == "__main__":
+    main()
